@@ -14,7 +14,7 @@ use constant LHS_PROCESS_EVENT => '<process>';
 use constant CLOSEANYSCOPE_PRIORITY => -1000;
 use constant RESETANYDATA_PRIORITY => -2000;
 
-our $VERSION = '0.46'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 
 sub new {
@@ -23,7 +23,7 @@ sub new {
     my $self = $class->SUPER();
 
     if (! defined($outerSelf) || ref($outerSelf) ne 'MarpaX::Languages::C::AST') {
-      croak 'outerSelf must be a reference to MarpaX::Languages::C::AST';
+      croak 'outerSelf must be a reference to MarpaX::Languages::C::AST'
     }
 
     $self->hscratchpad('_impl', $outerSelf->{_impl});
@@ -90,7 +90,7 @@ sub new {
                                           counters => {
                                                        'structContext' => [ 'structContextStart[]', 'structContextEnd[]', 'level' ]
                                                       },
-                                          process_priority => CLOSEANYSCOPE_PRIORITY - 1,
+                                          process_priority => CLOSEANYSCOPE_PRIORITY - 1
                                          }
                                         )
         );
@@ -121,7 +121,7 @@ sub new {
                                                    [ 'functionDefinitionCheck1declarationList',       [ [ 'storageClassSpecifierTypedef', 'typedef' ] ] ]
                                                  ],
                                           method => \&_functionDefinitionCheck1,
-                                          process_priority => CLOSEANYSCOPE_PRIORITY + 1,
+                                          process_priority => CLOSEANYSCOPE_PRIORITY + 1
                                          }
                                         )
         );
@@ -131,7 +131,7 @@ sub new {
                                           rhs => [ [ 'functionDefinitionCheck2declarationSpecifiers', [ [ 'storageClassSpecifierTypedef', 'typedef' ] ] ],
                                                  ],
                                           method => \&_functionDefinitionCheck2,
-                                          process_priority => CLOSEANYSCOPE_PRIORITY + 1,
+                                          process_priority => CLOSEANYSCOPE_PRIORITY + 1
                                          }
                                         )
         );
@@ -156,7 +156,7 @@ sub new {
                                           counters => {
                                                        'structContext' => [ 'structContextStart[]', 'structContextEnd[]', 'level' ]
                                                       },
-                                          method => \&_parameterDeclarationCheck,
+                                          method => \&_parameterDeclarationCheck
                                          }
                                         )
         );
@@ -171,7 +171,7 @@ sub new {
                      method =>  [ \&_enumerationConstantIdentifier_optimized, $outerSelf->{_impl}, $outerSelf->{_scope} ],
                      option => MarpaX::Languages::C::AST::Callback::Option->new
                      (
-                      condition => [ [ 'auto' ] ],
+                      condition => [ [ 'auto' ] ]
                      )
                     )
         );
@@ -201,7 +201,7 @@ sub new {
                                    ],
                       topic => {'fileScopeDeclarator' => 1,
                                 'reenterScope' => 1},
-                      topic_persistence => 'any',
+                      topic_persistence => 'any'
                      )
                     )
         );
@@ -236,17 +236,17 @@ sub new {
     # can cache everything that is intensive. Take care, any configuration data to Callback becomes then static.
     #
     foreach ($self, @callbacks) {
-      $_->cache();
+      $_->cache()
     }
 
-    return $self;
+    return $self
 }
 # ----------------------------------------------------------------------------------------
 sub _closeAnyScope {
     my ($method, $callback, $eventsp, $scope) = @_;
 
     while ($scope->parseScopeLevel >= 1) {
-      $scope->doExitScope();
+      $scope->doExitScope()
     }
 }
 # ----------------------------------------------------------------------------------------
@@ -254,7 +254,7 @@ sub _resetAnyData {
     my ($method, $callback, $eventsp, @callbacks) = @_;
 
     foreach (@callbacks) {
-      $_->exec(LHS_RESET_EVENT);
+      $_->exec(LHS_RESET_EVENT)
     }
 }
 # ----------------------------------------------------------------------------------------
@@ -264,12 +264,12 @@ sub _enumerationConstantIdentifier {
     my $impl = $callback->hscratchpad('_impl');
 
     my $enum = lastCompleted($impl, 'enumerationConstantIdentifier');
-    $callback->hscratchpad('_scope')->parseEnterEnum($enum, startAndLength($impl));
+    return $callback->hscratchpad('_scope')->parseEnterEnum($enum, startAndLength($impl))
 }
 sub _enumerationConstantIdentifier_optimized {
     # my ($method, $callback, $eventsp, $impl, $scope) = @_;
 
-    return $_[4]->parseEnterEnum(lastCompleted($_[3], 'enumerationConstantIdentifier'), startAndLength($_[3]));
+    return $_[4]->parseEnterEnum(lastCompleted($_[3], 'enumerationConstantIdentifier'), startAndLength($_[3]))
 }
 # ----------------------------------------------------------------------------------------
 sub _parameterDeclarationCheck {
@@ -286,7 +286,7 @@ sub _parameterDeclarationCheck {
     my $nbTypedef = $#{$parameterDeclarationdeclarationSpecifiers};
     if ($nbTypedef >= 0) {
         my ($start_lengthp, $line_columnp, $last_completed)  = @{$parameterDeclarationdeclarationSpecifiers->[0]};
-        logCroak("[%s[%d]] %s is not valid in a parameter declaration\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')));
+        logCroak("[%s[%d]] %s is not valid in a parameter declaration\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')))
     }
     #
     # By definition parameterDeclarationCheckDeclarator contains only directDeclaratorIdentifier
@@ -296,7 +296,7 @@ sub _parameterDeclarationCheck {
     # We are called at every parameterDeclarationCheck, and parameterDeclarationCheckDeclarator is an aggregation
     # of all directDeclaratorIdentifier. We don't need this data anymore
     #
-    $callback->reset_topic_fired_data('parameterDeclarationCheckDeclarator$');
+    return $callback->reset_topic_fired_data('parameterDeclarationCheckDeclarator$')
 }
 # ----------------------------------------------------------------------------------------
 sub _functionDefinitionCheck1 {
@@ -314,13 +314,13 @@ sub _functionDefinitionCheck1 {
     my $nbTypedef1 = $#{$functionDefinitionCheck1declarationSpecifiers};
     if ($nbTypedef1 >= 0) {
         my ($start_lengthp, $line_columnp, $last_completed)  = @{$functionDefinitionCheck1declarationSpecifiers->[0]};
-        logCroak("[%s[%d]] %s is not valid in a function declaration specifier\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')));
+        logCroak("[%s[%d]] %s is not valid in a function declaration specifier\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')))
     }
 
     my $nbTypedef2 = $#{$functionDefinitionCheck1declarationList};
     if ($nbTypedef2 >= 0) {
         my ($start_lengthp, $line_columnp, $last_completed)  = @{$functionDefinitionCheck1declarationList->[0]};
-        logCroak("[%s[%d]] %s is not valid in a function declaration list\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')));
+        logCroak("[%s[%d]] %s is not valid in a function declaration list\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')))
     }
 }
 sub _functionDefinitionCheck2 {
@@ -336,7 +336,7 @@ sub _functionDefinitionCheck2 {
     my $nbTypedef = $#{$functionDefinitionCheck2declarationSpecifiers};
     if ($nbTypedef >= 0) {
         my ($start_lengthp, $line_columnp, $last_completed)  = @{$functionDefinitionCheck2declarationSpecifiers->[0]};
-        logCroak("[%s[%d]] %s is not valid in a function declaration specifier\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')));
+        logCroak("[%s[%d]] %s is not valid in a function declaration specifier\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')))
     }
 }
 # ----------------------------------------------------------------------------------------
@@ -360,10 +360,10 @@ sub _declarationCheck {
         # Take the second typedef
         #
         my ($start_lengthp, $line_columnp, $last_completed)  = @{$declarationCheckdeclarationSpecifiers->[1]};
-        logCroak("[%s[%d]] %s cannot appear more than once\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')));
+        logCroak("[%s[%d]] %s cannot appear more than once\n%s\n", whoami(__PACKAGE__), $callback->currentTopicLevel, $last_completed, showLineAndCol(@{$line_columnp}, $callback->hscratchpad('_sourcep')))
     }
 
-    _enterOrObscureTypedef($callback, $nbTypedef, $declarationCheckinitDeclaratorList);
+    return _enterOrObscureTypedef($callback, $nbTypedef, $declarationCheckinitDeclaratorList)
 }
 # ----------------------------------------------------------------------------------------
 sub _enterOrObscureTypedef {
@@ -375,9 +375,9 @@ sub _enterOrObscureTypedef {
     my ($start_lengthp, $line_columnp, $last_completed, %counters)  = @{$_};
     if (! $counters{structContext}) {
       if ($nbTypedef >= 0) {
-        $scope->parseEnterTypedef($last_completed, $start_lengthp);
+        $scope->parseEnterTypedef($last_completed, $start_lengthp)
       } else {
-        $scope->parseObscureTypedef($last_completed);
+        $scope->parseObscureTypedef($last_completed)
       }
     }
   }
@@ -385,12 +385,12 @@ sub _enterOrObscureTypedef {
 # ----------------------------------------------------------------------------------------
 sub _enterScopeCallback {
     foreach (@_) {
-        $_->pushTopicLevel();
+        $_->pushTopicLevel()
     }
 }
 sub _exitScopeCallback {
     foreach (@_) {
-        $_->popTopicLevel();
+        $_->popTopicLevel()
     }
 }
 # ----------------------------------------------------------------------------------------
@@ -402,7 +402,7 @@ sub _storage_helper {
     my %counters = ();
     foreach (keys %{$countersHashp}) {
       my $counterDatap = $callback->topic_fired_data($_) || [0];
-      $counters{$_} = $counterDatap->[0] || 0;
+      $counters{$_} = $counterDatap->[0] || 0
     }
     #
     # The event name, by convention, is 'event$' or '^$event'
@@ -412,17 +412,17 @@ sub _storage_helper {
     my $g1 = $impl->current_g1_location();
     my ($start, $length) = $impl->g1_location_to_span($g1);
     if (substr($event, 0, 1) eq '^') {
-        $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), %counters ];
+        $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), %counters ]
     } elsif (substr($event, -1, 1) eq '$') {
         if (defined($callbackValue)) {
-          $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), &$callbackValue(), %counters ];
+          $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), &$callbackValue(), %counters ]
         } else {
           substr($event, -1, 1, '');
-          $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), $fixedValue || lastCompleted($impl, $event), %counters ];
+          $rc = [ [ $start, $length ], lineAndCol($impl, $g1, $start), $fixedValue || lastCompleted($impl, $event), %counters ]
         }
     }
 
-    return $rc;
+    return $rc
 }
 sub _storage_helper_optimized {
     my ($method, $callback, $eventsp, $event, $countersHashp, $fixedValue, $callbackValue, $impl) = @_;
@@ -432,7 +432,7 @@ sub _storage_helper_optimized {
     my %counters = ();
     foreach (keys %{$countersHashp}) {
       my $counterDatap = $callback->topic_fired_data($_) || [0];
-      $counters{$_} = $counterDatap->[0] || 0;
+      $counters{$_} = $counterDatap->[0] || 0
     }
     #
     # The event name, by convention, is 'event$' or '^$event'
@@ -443,17 +443,17 @@ sub _storage_helper_optimized {
     my ($start, $length) = $_[7]->g1_location_to_span($g1);
 
     if (substr($event, 0, 1) eq '^') {
-        $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), %counters ];
+        $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), %counters ]
     } elsif (substr($event, -1, 1) eq '$') {
         if (defined($callbackValue)) {
-          $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), &$callbackValue(), %counters ];
+          $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), &$callbackValue(), %counters ]
         } else {
           substr($event, -1, 1, '');
-          $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), $_[5] || lastCompleted($_[7], $event), %counters ];
+          $rc = [ [ $start, $length ], lineAndCol($_[7], $g1, $start), $_[5] || lastCompleted($_[7], $event), %counters ]
         }
     }
 
-    return $rc;
+    return $rc
 }
 # ----------------------------------------------------------------------------------------
 sub _inc_helper {
@@ -462,26 +462,26 @@ sub _inc_helper {
     my $old_value = $callback->topic_fired_data($topic)->[0] || 0;
     my $new_value = $old_value + $increment;
 
-    return $new_value;
+    return $new_value
 }
 sub _inc_helper_optimized {
     # my ($method, $callback, $eventsp, $topic, $increment) = @_;
 
-    return (($_[1]->topic_fired_data($_[3])->[0] || 0) + $_[4]);
+    return (($_[1]->topic_fired_data($_[3])->[0] || 0) + $_[4])
 }
 # ----------------------------------------------------------------------------------------
 sub _set_helper {
     my ($method, $callback, $eventsp, %topic) = @_;
 
     foreach (keys %topic) {
-      $callback->topic_fired_data($_, [ $topic{$_} ]);
+      $callback->topic_fired_data($_, [ $topic{$_} ])
     }
 }
 sub _set_helper_optimized {
     my (undef, undef, undef, %topic) = @_;
 
     foreach (keys %topic) {
-      $_[1]->topic_fired_data($_, [ $topic{$_} ]);
+      $_[1]->topic_fired_data($_, [ $topic{$_} ])
     }
 }
 # ----------------------------------------------------------------------------------------
@@ -489,10 +489,10 @@ sub _reset_helper {
     my ($method, $callback, $eventsp, @topics) = @_;
 
     my @rc = ();
-    return @rc;
+    return @rc
 }
 sub _reset_helper_optimized {
-    return ();
+    return ()
 }
 # ----------------------------------------------------------------------------------------
 sub _collect_and_reset_helper {
@@ -502,10 +502,10 @@ sub _collect_and_reset_helper {
     foreach (@topics) {
         my $topic = $_;
         push(@rc, @{$callback->topic_fired_data($topic)});
-        $callback->topic_fired_data($topic, []);
+        $callback->topic_fired_data($topic, [])
     }
 
-    return @rc;
+    return @rc
 }
 sub _collect_and_reset_helper_optimized {
     #
@@ -517,7 +517,7 @@ sub _collect_and_reset_helper_optimized {
         my $this = $_[1]->topic_fired_data($_);
         $_[1]->topic_fired_data($_, []);
         @{$this};
-    } @_[3..$#_];
+    } @_[3..$#_]
 
 }
 # ----------------------------------------------------------------------------------------
@@ -529,9 +529,9 @@ sub _subFire {
     if (defined($transformEventsp)) {
       my %tmp = ();
       my @transformEvents = grep {++$tmp{$_} == 1} map {$transformEventsp->{$_} || $_} @subEvents;
-      $subCallback->exec(@transformEvents);
+      $subCallback->exec(@transformEvents)
     } else {
-      $subCallback->exec(@subEvents);
+      $subCallback->exec(@subEvents)
     }
   }
 }
@@ -545,9 +545,9 @@ sub _subFire_optimized {
   if (@subEvents) {
     if (defined($_[6])) {
       my %tmp = ();
-      $_[4]->exec(grep {++$tmp{$_} == 1} map {$_[6]->{$_} || $_} @subEvents);
+      $_[4]->exec(grep {++$tmp{$_} == 1} map {$_[6]->{$_} || $_} @subEvents)
     } else {
-      $_[4]->exec(@subEvents);
+      $_[4]->exec(@subEvents)
     }
   }
 }
@@ -592,7 +592,7 @@ sub _register_rule_callbacks {
                           topic => {$counter => 1},
                           topic_persistence => $persistence,
                           condition => [ [ 'auto' ] ],  # == match on description
-                          priority => 999,
+                          priority => 999
                          )
                         )
                        );
@@ -608,7 +608,7 @@ sub _register_rule_callbacks {
                           topic => {$counter => 1},
                           topic_persistence => $persistence,
                           condition => [ [ 'auto' ] ],  # == match on description
-                          priority => 999,
+                          priority => 999
                          )
                         )
                        );
@@ -631,14 +631,14 @@ sub _register_rule_callbacks {
         #
         # Token value known in advance
         #
-        ($name, $value) = @{$_};
+        ($name, $value) = @{$_}
       } else {
-        ($name, $value) = ($_, undef);
+        ($name, $value) = ($_, undef)
       }
       my $event = $name . '$';
       ++$genomeEvents{$event};
       ++$rshProcessEvents{$event};
-      $genomeEventValues{$event} = $value;
+      $genomeEventValues{$event} = $value
     }
   }
   #
@@ -648,9 +648,9 @@ sub _register_rule_callbacks {
   foreach (keys %genomeEvents) {
         my ($fixedValue, $callbackValue) = (undef, undef);
         if (ref($genomeEventValues{$_}) eq 'CODE') {
-          $callbackValue = $genomeEventValues{$_};
+          $callbackValue = $genomeEventValues{$_}
         } else {
-          $fixedValue = $genomeEventValues{$_};
+          $fixedValue = $genomeEventValues{$_}
         }
         $callback->register(MarpaX::Languages::C::AST::Callback::Method->new
                             (
@@ -662,7 +662,7 @@ sub _register_rule_callbacks {
                               topic => {$_ => 1},
                               topic_persistence => 'level',
                               condition => [ [ 'auto' ] ],  # == match on description
-                              priority => 999,
+                              priority => 999
                              )
                             )
             );
@@ -685,12 +685,12 @@ sub _register_rule_callbacks {
         #
         # Token value known in advance
         #
-        ($name, $value) = @{$_};
+        ($name, $value) = @{$_}
       } else {
-        ($name, $value) = ($_, undef);
+        ($name, $value) = ($_, undef)
       }
       $genomeTopicsToUpdate{$name . '$'} = 1;
-      $genomeTopicsNotToUpdate{$name . '$'} = -1;
+      $genomeTopicsNotToUpdate{$name . '$'} = -1
     }
     #
     # rhs$ event will collect into rhs$ topic all Gx$ topics (created automatically if needed)
@@ -710,7 +710,7 @@ sub _register_rule_callbacks {
                           topic => {$rhsTopic => 1,
                                    %genomeTopicsNotToUpdate},
                           topic_persistence => 'level',
-                          priority => 1,
+                          priority => 1
                          )
                         )
         );
@@ -732,7 +732,7 @@ sub _register_rule_callbacks {
                     condition => [ [ 'auto' ] ],  # == match on description
                     topic => \%rhsTopicsNotToUpdate,
                     topic_persistence => 'level',
-                    priority => 1,
+                    priority => 1
                    )
                   )
                  );
@@ -749,7 +749,7 @@ sub _register_rule_callbacks {
                     condition => [ [ 'auto' ] ],  # == match on description
                     topic => \%rhsTopicsToUpdate,
                     topic_persistence => 'level',
-                    priority => 0,
+                    priority => 0
                    )
                   )
                  );
@@ -767,7 +767,7 @@ sub _register_rule_callbacks {
                     condition => [
                                   [ sub { return grep {exists($rshProcessEvents{$_})} @{$_[2]} }
                                   ]
-                                 ],
+                                 ]
                    )
                   )
                  );
@@ -794,7 +794,7 @@ sub _register_rule_callbacks {
                   )
                  );
 
-  return $callback;
+  return $callback
 }
 
 1;
@@ -811,7 +811,7 @@ MarpaX::Languages::C::AST::Callback::Events - Events callback when translating a
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 DESCRIPTION
 
