@@ -23,7 +23,7 @@ use constant {
     LEXEME_VALUE_INDEX => 2
 };
 use MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011::Scan::Actions;
-use File::ShareDir::ProjectDistDir 1.0 ':all', strict => 1;
+use File::ShareDir qw/dist_dir/;
 use File::Find qw/find/;
 use File::Spec;
 use File::Basename qw/basename/;
@@ -37,7 +37,7 @@ our $RESAMELINE = qr/(?:[ \t\v\f])*/;                        # i.e. WS* without
 our $REDEFINE = qr/^${RESAMELINE}#${RESAMELINE}define${RESAMELINE}((\w+)(?>[^\n\\]*)(?>\\.[^\n\\]*)*)/ms; # dot-matches-all mode, keeping ^ meaningful
 our $BALANCEDPARENS = qr/$RE{balanced}{-parens=>'()'}{-keep}/;
 
-our $VERSION = '0.46'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 
 # ----------------------------------------------------------------------------------------
@@ -2238,7 +2238,7 @@ MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011::Scan - Scan C source
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 SYNOPSIS
 
