@@ -7,23 +7,21 @@ use SUPER;
 
 # ABSTRACT: ISO ANSI C 2011 grammar actions in Scan mode
 
-our $VERSION = '0.46'; # VERSION
+our $VERSION = '0.47'; # VERSION
 
 
 #
 # Because Marpa is using $CODE{}
 #
 sub new {
-  super();
+  super()
 }
 
 sub nonTerminalSemantic {
-  super();
+  super()
 }
 
 sub getRuleDescription {
-  my ($self) = @_;
-
   my ($lhs, @rhs) = super();
 
   #
@@ -33,7 +31,7 @@ sub getRuleDescription {
                     $_ ne 'structContextEnd' &&
                     $_ ne 'WS_MANY'} @rhs;
 
-  return ($lhs, @okRhs);
+  return ($lhs, @okRhs)
 }
 
 1;
@@ -50,7 +48,7 @@ MarpaX::Languages::C::AST::Grammar::ISO_ANSI_C_2011::Scan::Actions - ISO ANSI C
 
 =head1 VERSION
 
-version 0.46
+version 0.47
 
 =head1 DESCRIPTION
 
